/*
  Persistence of Vision Ray Tracer Scene Description File

  --   
  Jaime Vives Piqueres, Aug-Sept 2004.

  IMPORTANT NOTE: there are some files missing! These are some photos from
  www.imageafter.com that I cannot redistribute. All the missing files are
  included from i_textures.inc, so you can see there the file names and 
  search for them on www.imageafter.com, or replace them with your own images.

  Sorry for the inconvenience...

*/
#version unofficial MegaPov 1.2;


// ***************
// *** globals ***
// ***************
#declare use_rad   =2;  // 0=off, 1=load, 2=save 
#declare use_radiosity=use_rad; // gs
#declare use_blur  =0; //x7
#declare use_area  =0; 
#declare use_media =0;
#declare use_build =1; // 2= blocks
#declare use_sidew =1;
#declare use_road  =1;
#declare use_chair =1;
#declare use_oranges=1;
#declare use_lamps =1;
#declare use_plants=1;
#declare use_acond =1;
#declare use_banner=1;
#declare use_cables=1;
#declare use_mycar =1;
#declare use_skymap=1; // precomputed cloudy sky
#declare trace_at_night=0;
global_settings{
 max_trace_level 6 
 assumed_gamma 1.5  // raised a bit for contrast
 #if (use_rad)
 radiosity{
  // save settings
  #if (use_rad=2) 
    pretrace_start 0.08 pretrace_end   0.01
    count 250 nearest_count 20 error_bound .25
    recursion_limit 1
    brightness 1.5
    always_sample off
    save_file "townstreet.rad"
    normal off
    media off
  #else
    // load settings  
    pretrace_start 1 pretrace_end 1 
    load_file "townstreet.rad" 
    error_bound .25
    recursion_limit 1
    always_sample off  
    brightness 1.5
    normal off
    media off
  #end
 }
 #end
}
#default{texture{finish{ambient 0}}}


// *************************
// *** standard includes ***
// *************************
#include "colors.inc"
#include "textures.inc"
#include "woods.inc"
#include "stones.inc"
#include "glass.inc"
#include "metals.inc"
#include "functions.inc"


// *******************************
// *** CIE & LIGHTSYS includes ***
// *******************************
#include "CIE.inc"
#include "lightsys.inc"          
#declare Lightsys_Brightness=.6;
// change white point to typical outdoor white balance
//CIE_ColorSystemWhitepoint(CIE_ColSys,Daylight2Whitepoint(6500))
CIE_ColorSystem(CIE_ColSys)
#include "espd_lightsys.inc"  // light spectrums
// spectral colors for pigments:
#include "rspd_aster.inc" // from the ASTER library
#include "rspd_jvp.inc"   // sampled by myself with a "EYE-ONE" spectometer


// **************************************
// *** Elements switches (0=off/1=on) ***
// **************************************
#declare use_atmosphere=0;
#declare r_sun=seed(8890);
//#declare r_sun=seed(2350);
//#declare r_sun=seed(515);
#declare r_wall=seed(789);
#declare r_clouds=seed(978);

// **************
// *** camera ***
// **************
// looking to the street
#declare clo=<1.9,1.65,-7>;
#declare cla=<0,2.05,0>;
//#declare clo=<1,1.65,-9.5>;
//#declare cla=<1,2,0>;
// to building l1
//#declare clo=<2,1,0>;
//#declare cla=<-2,1,0>;
// to buildings fronts
//#declare clo=<10,4,27.5>;
//#declare cla=<0,.4,26>;
camera{ 
 location clo
 up 0.032*y right 0.024*x
 direction 0.050*z
 look_at cla
 #if (use_blur>0)
  aperture .05 blur_samples 7*use_blur 
//  focal_point cla
  focal_point <-1.4,.1,1>
 #end
}

// ****************************
// *** sun & sky parameters ***
// ****************************
// skylight params:
#declare Current_Turbidity=3; // skylight turbidity (influences haze)
#declare Intensity_Mult   =1.5; // skylight intensity
#declare Max_Vertices  =1000; // skylight mesh resolution
#declare Sun_Size      =5000; // aparent size of the sun
// haze params:
#declare Haze_Height    =200; // keep it below the cumulus to avoid container artifacts  
#declare Haze_Distance=50;  // turbidity also affects distance
#declare Haze_Tint     =0;  // 0=Sky color, 1=Sun color, 2=Horizon color
// precomputed cloudy skymap (see skymap.pov)
// sun placement settings (uses rand seed if these are not specified)
#declare sm_rot=40; // skymap rotate
#declare Az   =90+sm_rot;
#declare Al   =51;
#declare North=z;
#include "i_sky.inc"
#if (use_skymap)
sphere{0, 
 DomeSize*.9 // inside the Skylight dome
 hollow no_shadow
 pigment{image_map{hdr "skymap-050916-al51" map_type 1 interpolate 2}}
 finish{ambient Intensity_Mult diffuse 0}
 scale <-1,1,1> rotate (-90+sm_rot)*y
}
#end


// ****************
// *** TEXTURES ***
// ****************
#include "i_textures.inc"


// *** SETUP ***
#declare r_bd=seed(67867);
#include "i_func-mac.inc"
#include "i_bd_create.inc"
#declare street=
union{
 #if (use_build>0)
 // faked previous left building
 box{-.5,.5 scale <1,5,6>
  pigment{image_map{jpeg i_concrete4} rotate 90*y}
  translate <-2.5,2.5,-5>
 }
 // 1st left building
 object{bl1 rotate -90*y translate -2*x}
 // 2nd left building
 object{bl2 rotate -90*y translate <-1.98,0,4.5>}
 // 3rd left building
 object{bl3 rotate -90*y rotate 10*y translate <-1.6,0,9>}
 // 4th left building
 object{bl4 rotate -90*y rotate 10*y translate <-1.6+.7,0,12.9>}
 // 5th left building
 object{bl5 rotate -90*y rotate 10*y translate <-.09,0,17.09>}
 // 6th left building
 object{bl6 rotate -90*y rotate 10*y translate <.8,0,22>}
 // 7th left building
 object{bl7 rotate -90*y rotate 20*y translate <2,0,26.4>}
 // 8th left building
 object{bl8 rotate -90*y rotate 20*y translate <3.4,0,30>}
 #end
 // floor
 #if (use_sidew)
 #include "sidewalk.inc"
 object{
  acera(t_sidewalk,texture{t_wall_paint2 rotate 90*x},1000*rand(r_bd))
  rotate -90*y
  translate <-1.3,-.07,0>
 }
 object{
  acera(t_sidewalk,texture{t_wall_paint2 rotate 90*x},1000*rand(r_bd))
  rotate -90*y
  rotate 10*y
  translate <.5,-.07,17>
 }
 #end
 #if (use_road)
 #include "i_road.inc"
 object{
  tiled_road2(t_road,1000*rand(r_bd))
  translate <0,-.09,1>
 }
 object{
  tiled_road(t_road,1000*rand(r_bd))
  translate <0,-.09,5>
 }
 object{
  tiled_road(t_road,1000*rand(r_bd))
  translate <3,-.09,1>
 }
 object{
  tiled_road(t_road,1000*rand(r_bd))
  translate <3,-.09,5>
 }
 intersection{
  object{tiled_road(t_road,1000*rand(r_bd)) translate 2*z rotate 10*y}
  plane{z,0 inverse}
  translate <0,-.09,7>
 }
 intersection{
  object{tiled_road(t_road,1000*rand(r_bd)) translate 2*z rotate 10*y}
  plane{z,0 inverse}
  translate <3,-.09,7>
 }
 object{
  tiled_road(t_road,1000*rand(r_bd))
  rotate 10*y
  translate <1,-.09,12.8>
 }
 object{
  tiled_road(t_road,1000*rand(r_bd))
  rotate 10*y
  translate <4,-.09,12.8>
 }
 object{
  tiled_road(t_road,1000*rand(r_bd))
  rotate 10*y
  translate <2,-.09,12.8+4>
 }
 object{
  tiled_road(t_road,1000*rand(r_bd))
  rotate 10*y
  translate <3,-.09,12.8+4+4>
 }
 #end
 plane{y,-0.2 texture{t_floor scale .1} }
 // right buildings (fake)
 object{bl2 rotate 90*y translate <5,0,0>}
 box{-.5,.5 scale <1,7.5,8>
  pigment{image_map{jpeg i_concrete4} rotate 90*y}
  translate <6,7.5*.5,-5>
 }
 box{-.5,.5 scale <1,5,8>
  pigment{image_map{jpeg i_concrete4} rotate 90*y}
  translate <5,2.5,-11.5>
 }
 box{-.5,.5 scale <1,5,8>
  pigment{image_map{jpeg i_concrete4} rotate 90*y}
  translate <5,2.5,-.5>
 }
 box{-.5,.5 scale <1,6,8>
  pigment{image_map{jpeg i_concrete4} rotate 90*y}
  translate <5,3,4.5>
 }
 box{-.5,.5 scale <1,5,8> rotate 10*y
  pigment{image_map{jpeg i_concrete4} rotate 90*y}
  translate <5.5,2.5,10> 
 }
 box{-.5,.5 scale <1,6,8> rotate 10*y
  pigment{image_map{jpeg i_concrete4} rotate 90*y}
  translate <6.5,3,15> 
 }
}
object{street}


// cars
#if (use_mycar)
// required includes
#declare use_final_text=1;
#include "i_car-paints.inc"
#include "i_citroen_gs.inc"
// 1) custom colors for paints:
#declare c1=Gold+Gray50; #declare c2=Gray10;
// 2) texture with paint colors and predefined finish macros
#if (use_final_text<2)
 #declare t_custom_paint=
 metallized_paint(c1,c2,cv,f_matte,f_varnish)  // metallized paint
// texture{ pigment{c1} finish{f_varnish}}  // plain paint
#else 
 #declare t_custom_paint=texture{pigment{Gray}}
#end
// 3) create and place the car:
#declare car=object{jvp_citroen_gs(t_custom_paint,15) scale .85}
object{car rotate 180*y translate <0,-.1,3>}
#include "tran_mini.inc"
object{MiniCooper scale 1.05 rotate 10*y translate <.35,-.05,9.2>}
#end

/*
#declare rmin=.1; #declare rmax=.5;
#include "i_citroen_gs.inc"
//#declare c1=SteelBlue*.5+Gray; #declare c2=Gray10;
#if (use_radiosity<2)
#declare t_custom_paint=
metallized_paint(c1,c2,cv,f_matte,f_varnish)  // metallized paint
#else
#declare t_custom_paint=texture{pigment{Gray}}
#end
#declare Citroen_GS=object{jvp_citroen_gs(t_custom_paint,15) scale .85}
object{Citroen_GS rotate 180*y translate <0,-.1,3>}
#include "tran_mini.inc"
object{MiniCooper scale 1.05 rotate 10*y translate <.35,-.05,9.2>}
*/


// *** SPANISH CHAIR (Tipical valencian one)
#if (use_chair)
#declare r_chair=seed(67);
#declare t_chair_wood=texture{T_Wood11 scale 12 rotate -90*x finish{metallic}}
#declare t_chair_seat=
texture{
 gradient z
 texture_map{
   [0.0 pigment{DarkTan/3} normal{gradient x 1 }]
   [0.5 T_Wood11 normal{gradient x 1 } finish{Shiny}]
   [1.0 pigment{DarkTan/3} normal{gradient x 1 }]
 }
 rotate 90*y
 scale 1.1
}
#declare rad_bg=.6;
#declare rad_sg=.45;
#declare rad_leg=2.1;
#include "i_chair.inc"
object{silla scale .009 rotate -49*y
 translate <-1.4,.01,1>
}
#end


// *** ORANGES BOWL ON THE CHAIR ***
#if (use_oranges)
#include "i_orange.inc"
#include "i_bowl1.inc"
#declare t_bowl=
texture{
 pigment{quilted} scale .1
}
#declare price_carboard=
box{-.5,.5
 pigment{image_map{png "im_1euro"} translate -.5}
 finish{diffuse 1}
 scale <15,15,.2>
}
#declare r_orng=seed(6537);
union{
 object{bowl1(texture{t_bowl}) scale 10}
 #declare iorng=0;
 #declare norng=7;
 #while (iorng<norng)
  object{orange rotate 360*rand(r_orng)
   translate -int(8*rand(r_orng))*z
   rotate 90*rand(r_orng)*x
   rotate 360*rand(r_orng)*y
   translate 6*y
  }
  #declare iorng=iorng+1;
 #end
 object{price_carboard scale .5 rotate 10*x rotate -45*y translate <2,10,3>}
 scale .015 rotate 45*y
 translate <-1.4,.3,1>
}
#end


// *** STREET LAMPS ***
#if (use_lamps)
#declare t_pillar_metal=
texture{
 pigment{DarkBrown*.1+Gray10}
 finish{specular .33 metallic diffuse .67}
}
#include "i_slamp.inc"
object{slamp scale .01 rotate -90*y
 translate <-1.675,2.4,1.8>
}
object{slamp scale .01 rotate 90*y
 translate <4.5,2.5,6.7>
}
object{slamp scale .01 rotate -80*y
 translate <-1.0,2.4,10.47>
}
object{slamp scale .01 rotate 100*y
 translate <4.5,2.4,14.8>
}
object{slamp scale .01 rotate -80*y
 translate <.7,2.7,19.3>
}
#end


// *** TV ANTENNAS ***
#declare antenna1=
union{
 // mast
 cylinder{<0,-50,0>,<0,200,0>,2}
 // low grille
 cylinder{<-30,170,0>,<30,170,0>,1.5}
 cylinder{<0,170,-20>,<0,170,20>,0.5 translate -30*x}
 cylinder{<0,170,-20>,<0,170,20>,0.5 translate -20*x}
 cylinder{<0,170,-20>,<0,170,20>,0.5 translate -10*x}
 cylinder{<0,170,-20>,<0,170,20>,0.5 translate   0*x}
 cylinder{<0,170,-20>,<0,170,20>,0.5 translate  10*x}
 cylinder{<0,170,-20>,<0,170,20>,0.5 translate  20*x}
 cylinder{<0,170,-20>,<0,170,20>,0.5 translate  30*x}
 // middle grille
 union{
  cylinder{<0,148,0>,<0,152,0>,2.2}
  cylinder{<0,150,0>,<50,150,0>,1.5}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 5*x}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 10*x}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 15*x}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 20*x}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 25*x}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 30*x}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 35*x}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 40*x}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 45*x}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 50*x}
  rotate -30*y
 }
 // upper grille
 union{
  cylinder{<0,196,0>,<0,200,0>,2.2}
  cylinder{<0,198,0>,<30,198,0>,1.6}
  cylinder{<0,198,-10>,<0,198,10>,.6 translate 5*x}
  cylinder{<0,198,-10>,<0,198,10>,.6 translate 10*x}
  cylinder{<0,198,-10>,<0,198,10>,.6 translate 15*x}
  cylinder{<0,198,-10>,<0,198,10>,.6 translate 20*x}
  cylinder{<0,198,-10>,<0,198,10>,.6 translate 25*x}
  cylinder{<0,198,-10>,<0,198,10>,.6 translate 30*x}
  rotate 20*y
 }
 // cables
 cylinder{<0,130,0>,<0,0,-50>,.4}
 cylinder{<0,130,0>,<0,0,-50>,.4 rotate 180*y}
 texture{pigment{Gray} finish{ambient 0}}
}
#declare antenna2=
union{
 // mast
 cylinder{<0,-50,0>,<0,200,0>,2}
 // middle grille
 union{
  cylinder{<0,148,0>,<0,152,0>,2.2}
  cylinder{<0,150,0>,<50,150,0>,1.5}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 5*x}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 10*x}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 15*x}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 20*x}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 25*x}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 30*x}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 35*x}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 40*x}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 45*x}
  cylinder{<0,150,-10>,<0,150,10>,.5 translate 50*x}
  rotate -30*y
 }
 // upper grille
 union{
  cylinder{<0,196,0>,<0,200,0>,2.2}
  cylinder{<0,198,0>,<30,198,0>,1.6}
  cylinder{<0,198,-10>,<0,198,10>,.6 translate 5*x}
  cylinder{<0,198,-10>,<0,198,10>,.6 translate 10*x}
  cylinder{<0,198,-10>,<0,198,10>,.6 translate 15*x}
  cylinder{<0,198,-10>,<0,198,10>,.6 translate 20*x}
  cylinder{<0,198,-10>,<0,198,10>,.6 translate 25*x}
  cylinder{<0,198,-10>,<0,198,10>,.6 translate 30*x}
  rotate 20*y
 }
 // cables
 cylinder{<0,130,0>,<0,0,-50>,.4}
 cylinder{<0,130,0>,<0,0,-50>,.4 rotate 180*y}
 texture{Chrome_Texture finish{ambient 0}}
}
#declare antenna3=
union{
 // mast
 cylinder{<0,-50,0>,<0,200,0>,2}
 // upper grille
 union{
  cylinder{<0,196,0>,<0,200,0>,2.2}
  cylinder{<0,198,0>,<30,198,0>,1.6}
  cylinder{<0,198,-10>,<0,198,10>,.6 translate 5*x}
  cylinder{<0,198,-10>,<0,198,10>,.6 translate 10*x}
  cylinder{<0,198,-10>,<0,198,10>,.6 translate 15*x}
  cylinder{<0,198,-10>,<0,198,10>,.6 translate 20*x}
  cylinder{<0,198,-10>,<0,198,10>,.6 translate 25*x}
  cylinder{<0,198,-10>,<0,198,10>,.6 translate 30*x}
  rotate 20*y
 }
 // cables
 cylinder{<0,130,0>,<0,0,-50>,.4}
 cylinder{<0,130,0>,<0,0,-50>,.4 rotate 180*y}
 texture{Chrome_Texture finish{ambient 0}}
}
object{antenna1 scale .01 translate <-2,5,9>}
object{antenna2 scale .01 rotate 80*y translate <-2,7,15>}
object{antenna3 scale .01 rotate 200*y translate <-2,7,19>}
object{antenna1 scale .01 rotate 200*y translate <-1,7,19>}
object{antenna2 scale .01 rotate 200*y translate <0,7,25>}


// *** PLANTS ***
#if (use_plants)
#declare ff=.2;
#declare t_leaf=
texture{
 pigment{
  gradient x
  cubic_wave
  turbulence .1
  color_map{
   [0.00 White filter ff]
   [0.01 DarkGreen filter ff]
   [1.00 Bronze filter ff]
  }
 }
 scale 2
}
#declare t_leaf2=
texture{
 pigment{
  bumps
  color_map{
   [0.0 Gray*.1+DarkGreen*.9 filter ff]
   [1.0 ForestGreen*.5+Gold*.25 filter ff]
  }
 }
 finish{Shiny}
 scale 2
}
#declare t_leaf3=
texture{
 pigment{
  gradient x
  cubic_wave
  turbulence .1
  color_map{
   [0.0 DarkOliveGreen filter ff]
   [0.4 DarkOliveGreen filter ff]
   [0.5 Gold filter ff]
   [0.6 DarkGreen filter ff]
   [1.0 DarkGreen filter ff]
  }
 }
 scale 2
}
#declare t_leaf4=
texture{
 pigment{
  bumps
  color_map{
   [0.0 Gray*.2+DarkGreen*.8 filter ff]
   [1.0 Green*.2+Gold*.5 filter ff]
  }
 }
 finish{Phong_Shiny}
 scale 3
}
#include "i_plants.inc"
#declare r_p1=seed(69);
#declare r_p2=seed(119);
#declare r_p3=seed(98);
#declare r_p4=seed(937);
#declare r_p5=seed(64);
#declare r_p6=seed(76);
#declare r_p7=seed(38);
#declare r_p8=seed(41);
#declare r_p9=seed(176);
#declare achmea1=
union{
 object{achmea_plant1(10,.1,3,16,4,t_leaf,r_p1)
  rotate 360*rand(r_p1)*y
  translate 10*y
 }
 object{pot1 scale .9}
 scale .01
}
#declare hanging1=
union{
 object{hanging_plant2(8,32,16,t_leaf,r_p2)
  rotate 360*rand(r_p2)*y
  translate 4*y
 }
 object{pot1 scale .9}
 scale .01
}
#declare hanging2=
union{
 object{hanging_plant(10,32,16,t_leaf2,r_p3)
  rotate 360*rand(r_p3)*y
  translate 6*y
 }
 object{pot1 scale .9}
 scale .01
}
#declare hanging3=
union{
 object{hanging_plant3(8,32,16,t_leaf3,r_p4)
  rotate 360*rand(r_p4)*y
  translate 10*y
 }
 object{pot7}
 scale .01
}
#declare hanging4=
union{
 object{hanging_plant(8,32,16,t_leaf4,r_p7)
  rotate 360*rand(r_p7)*y
  translate 7*y
 }
 object{pot5}
 scale .006
}
#declare achmea2=
union{
 object{achmea_plant2(10,.1,3,4,8,t_leaf,r_p8)
  scale 1.2
  rotate 360*rand(r_p8)*y
  translate 10*y
 }
 object{pot2}
 scale .01
}
// building 1L
object{achmea1 translate <-1.95,3.25,.9>}
object{hanging1 translate <-1.94,3.25,1.2>}
// bd2L
object{hanging2 rotate -7*z translate <-1.95,4.05,4>}
object{hanging3 translate <-1.95,4.05,4.2>}
object{hanging4 translate <-1.95,4.05,5.9>}
object{achmea2 translate <-1.9,4.05,6.1>}
//bd3L
union{
 object{hanging1 rotate -9*z }
 object{hanging2 rotate -9*z translate .4*z}
 object{hanging3 rotate -9*z translate .8*z}
 rotate 10*y
 translate <-1.6,3.1,7.5>
}
union{
 object{hanging3 rotate -9*z }
 object{hanging1 rotate -9*z translate .4*z}
 object{hanging2 rotate -9*z translate .8*z}
 rotate 10*y
 translate <-1.28,3.1,7.5+1.9>
}
//bd4L
union{
 object{hanging1 rotate -9*z }
 object{hanging4 rotate -9*z translate .4*z}
 object{hanging2 rotate -9*z translate .8*z}
 rotate 10*y
 translate <-.55,3.2,11.6>
}
union{
 object{hanging3 rotate -9*z }
 object{hanging2 rotate -9*z translate .4*z}
 object{hanging4 rotate -9*z translate .8*z}
 rotate 10*y
 translate <-.25,3.2,11.6+2>
}
object{achmea1 translate <-.85,2.8,11.8>}
object{achmea2 translate <-.8,2.8,11.9>}
//bd5L
union{
 object{hanging3 rotate -9*z }
 object{hanging2 rotate -9*z translate .4*z}
 object{hanging1 rotate -9*z translate .8*z}
 rotate 10*y
 translate <-.16,3.9,15.3>
}
union{
 object{hanging1 rotate -9*z }
 object{hanging2 rotate -9*z translate .4*z}
 object{hanging3 rotate -9*z translate .8*z}
 object{hanging4 rotate -9*z translate .11*z}
 rotate 10*y
 translate <.3,3.9,15.2+2.6>
}
// bd6L
object{achmea1 translate <.7,4.05,20.8>}
object{achmea2 translate <.7,4.05,20.9>}
#end


// cables
#if (use_cables)
#declare r_cbl=seed(5628);
#declare cable=
intersection{
 torus{20,.01 rotate 90*x}
 plane{y,-19.6}
 pigment{Gray10}
}
object{cable translate <2,20+5.7,-2>}
object{cable translate <2,20+5.7,6.85>}
object{cable rotate 10*y translate <3.5,20+5.7,14.1>}
// wall cables
#declare nwp=29;
#declare a_wp=array[nwp]
#declare a_wp[0]=<-1.8,2.45,-2>;
#declare a_wp[1]=<-1.8,2.45,-1>;
#declare a_wp[2]=<-1.8,2.45,1>;
#declare a_wp[3]=<-1.8,2.45,1.9>;
#declare a_wp[4]=<-1.8,3,1.9>;
#declare a_wp[5]=<-1.8,3,3>;
#declare a_wp[6]=<-1.8,3,4>;
#declare a_wp[7]=<-1.8,3,5>;
#declare a_wp[8]=<-1.8,3,6>;
#declare a_wp[9]=<-1.8,3,7>;
#declare a_wp[10]=<-1.8,2.45,7>;
#declare a_wp[11]=<-1.75,2.45,7>;
#declare a_wp[12]=<-1.58,2.45,8>;
#declare a_wp[13]=<-1.4,2.45,9>;
#declare a_wp[14]=<-1.23,2.45,10>;
#declare a_wp[15]=<-1.05,2.45,11>;
#declare a_wp[16]=<-.86,2.45,12>;
#declare a_wp[17]=<-.68,2.45,13>;
#declare a_wp[18]=<-.52,2.45,14>;
#declare a_wp[19]=<-.35,2.45,14.6>;
#declare a_wp[20]=<-.35,3,14.6>;
#declare a_wp[21]=<-.11,3,16>;
#declare a_wp[22]=<.08,3,17>;
#declare a_wp[23]=<.25,3,18>;
#declare a_wp[24]=<.43,3,19>;
#declare a_wp[25]=<.63,3,20>;
#declare a_wp[26]=<.80,3,21>;
#declare a_wp[27]=<.99,3,22>;
#declare a_wp[28]=<1.1,3,23>;
// cable 1
#declare iwp=0;
sphere_sweep{cubic_spline,nwp
#while (iwp<nwp)
 a_wp[iwp]+<0,-.025+.05*rand(r_cbl),0>,.01
 #declare iwp=iwp+1;
#end
 pigment{Gray10}
}
// cable 2
#declare iwp=0;
sphere_sweep{b_spline,nwp
#while (iwp<nwp)
 a_wp[iwp]+<0,-.025+.05*rand(r_cbl),-.05+.1*rand(r_cbl)>,.005
 #declare iwp=iwp+1;
#end
 pigment{Gray30}
}
// cable 3
#declare iwp=0;
sphere_sweep{cubic_spline,nwp
#while (iwp<nwp)
 a_wp[iwp]+<0,-.05+.1*rand(r_cbl),-.05+.1*rand(r_cbl)>,.006
 #declare iwp=iwp+1;
#end
 pigment{Gray20}
}
// conexions boxes
#declare cnx_box=
union{
 intersection{
  superellipsoid{<.2,.1> rotate 90*x scale <.05,.125,.1>}
  plane{x,-0.01}
 }
 difference{
  intersection{
   superellipsoid{<.2,.1> rotate 90*x scale <.05,.125,.1>}
   plane{x,0.01 inverse}
  }
  cylinder{<-.2,0,-.05>,<.2,0,-.05>,.02}
 }
 cylinder{<0,-.15,.05>,<0,.15,.05>,.015}
 cylinder{<0,-.15,-.05>,<0,.15,-.05>,.015}
 texture{pigment{Gray*.5+DarkGreen*.5}
 normal{quilted scale .01}
 finish{Shiny}}
}
object{cnx_box translate <-1.8,2.7,1.7>}
object{cnx_box translate <-1.75,2.7,7>}
#end


// *** sewer ***
#declare sewer=
union{
 cylinder{<0,10,0>,<0,385,0>,6}
 cylinder{<0,385,0>,<0,395,-10>,6}
 sphere{<0,385,0>,6}
 sphere{<0,395,-10>,6}
 cylinder{<0,395,-10>,<0,415,-10>,6}
 sphere{<0,415,-10>,6}
 sphere{<0,425,0>,6}
 cylinder{<0,415,-10>,<0,425,0>,6}
 cylinder{<0,425,0>,<0,830,0>,6}
 sphere{<0,830,0>,6}
 cylinder{<0,830,0>,<0,860,-45>,6}
 cylinder{<0,110,0>,<0,120,0>,7.5}
 cylinder{<0,230,0>,<0,240,0>,7.5}
 cylinder{<0,365,0>,<0,375,0>,7.5}
 cylinder{<0,400,-10>,<0,410,-10>,7.5}
 cylinder{<0,435,0>,<0,445,0>,7.5}
 cylinder{<0,555,0>,<0,565,0>,7.5}
 cylinder{<0,675,0>,<0,685,0>,7.5}
 cylinder{<0,810,0>,<0,820,0>,7.5}
 cylinder{<0,10,0>,<0,20,0>,7.5}
 intersection{
  difference{
   torus{8,6 rotate <-90,90,0>}
   torus{8,5.8 rotate <-90,90,0>}
  }
  plane{y,0}
  plane{z,0 inverse}
  translate <0,10,-8>
 }
 intersection{
  cylinder{<-10,870,-45>,<600,870,-45>,7.5}
  plane{y,870}
 }
 texture{t_rusty1 scale 800}
}
#declare sewer2=
union{
 cylinder{<0,10,0>,<0,385,0>,6}
 cylinder{<0,385,0>,<0,395,-10>,6}
 sphere{<0,385,0>,6}
 sphere{<0,395,-10>,6}
 cylinder{<0,395,-10>,<0,415,-10>,6}
 sphere{<0,415,-10>,6}
 sphere{<0,425,0>,6}
 cylinder{<0,415,-10>,<0,425,0>,6}
 cylinder{<0,425,0>,<0,830,0>,6}
 sphere{<0,830,0>,6}
 cylinder{<0,830,0>,<0,875,-40>,6}
 cylinder{<0,110,0>,<0,120,0>,7.5}
 cylinder{<0,230,0>,<0,240,0>,7.5}
 cylinder{<0,365,0>,<0,375,0>,7.5}
 cylinder{<0,400,-10>,<0,410,-10>,7.5}
 cylinder{<0,435,0>,<0,445,0>,7.5}
 cylinder{<0,555,0>,<0,565,0>,7.5}
 cylinder{<0,675,0>,<0,685,0>,7.5}
 cylinder{<0,810,0>,<0,820,0>,7.5}
 cylinder{<0,10,0>,<0,20,0>,7.5}
 intersection{
  difference{
   torus{8,6 rotate <-90,90,0>}
   torus{8,5.8 rotate <-90,90,0>}
  }
  plane{y,0}
  plane{z,0 inverse}
  translate <0,10,-8>
 }
 intersection{
  cylinder{<-10,880,-40>,<620,880,-40>,7.5}
  plane{y,880}
 }
 texture{t_rusty2 scale 800}
}
object{sewer scale .007 rotate -90*y translate <-1.75,.1,2.1>}
object{sewer2 scale .007 rotate -80*y translate <-1.75+1.46,.1,2.1+5+4+4-.4>}
// sewer tap on the road
#declare t_sewer_tap=
texture{Rusty_Iron scale 20 finish{F_MetalA ambient 0}}
texture{pigment{Gray transmit .8}}
#include "i_sewer_tap.inc"
object{sewer_tap
 scale .19
 translate <.1,-.09,1.19>
}

#if (use_banner)
#declare banner=
union{
difference{
 box{-.5,.5 scale 1.05}
 box{-.5,.5 translate -.1*z}
 pigment{Gray10} finish{Glossy}
}
//box{-.5,.5
height_field{png "hf_cartel" translate -.5 rotate -90*x
 texture{
  pigment{image_map{png "im_cartel"} translate -.5}
  finish{Glossy}
 }
 scale <1,1,.05> translate -.49*z
}
 scale <438,126,40>*.005
}
object{banner rotate -90*y translate <-1.9,2.5,3.55>}
#end

#if (use_acond)
#include "i_acond.inc"
object{air_cond scale <-1,1,1>
 scale .009
 rotate -90*y
 translate <-1.675,2.85,.92>
}
object{air_cond scale <-1,1,1>
 scale .008
 rotate -90*y
 translate <-1.675,2.45,5>
}
object{air_cond scale <-1,1,1>
 scale .01
 rotate -80*y
 translate <.19,3.3,17>
}
#end


