// =========================================
// Demo file for a building front and a Mini Cooper model
// -----------------------------------------
// Made for Persistence of vision 3.6
//==========================================  
// Copyright 2004 Gilles Tran http://www.oyonale.com
// -----------------------------------------
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/2.0/ 
// or send a letter to Creative Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.
// You are free:
// - to copy, distribute, display, and perform the work
// - to make derivative works
// - to make commercial use of the work
// Under the following conditions:
// - Attribution. You must give the original author credit.
// - For any reuse or distribution, you must make clear to others the license terms of this work.
// - Any of these conditions can be waived if you get permission from the copyright holder.
// Your fair use and other rights are in no way affected by the above. 
//==========================================  

// Aug.2004 : modified by Jaime Vives Piqueres to only include the mini object

#include "transforms.inc"
//---------------------------------------
// Switches (the value 0 turns a switch off)
//---------------------------------------
#declare RadOK=0; // 0 = no rad, 1 = test rad, 2 = final rad
#declare MediaOK=0; // media = 1 creates a subtle haze
#declare SaveRadOK=0; // save radiosity data for pass 1
#declare LoadRadOK=0; // load radiosity data for pass 2
#declare AreaOK=0; // subtle area light
#declare Ref=1; // intensity of reflections, use 0 to turn off it completely

#declare BuildingOK=1; // building
#declare SidewalkOK=1; // sidewalk and road
#declare MiniOK=1; // Mini Cooper car

//---------------------------------------
// Mini Cooper
//---------------------------------------
#if (MiniOK=1)
    #debug "Mini\n"
    #declare V_WorldBoundMin = <-4.149374, -0.127721, -0.004524>;
    #declare V_WorldBoundMax = <5.696744, 23.635614, 10.148702>;
    #declare C_Paint= rgb <83,106,138>/255;
    #declare C_Paint_Roof = White*0.6;
    #declare C_Paint_Interior = rgb <229,206,157>/255;
    #declare angle_turn=-20; // rotation angle to turn the front wheels left (negative) or right (positive)
    #declare angle_move=30; // forward rotation angle for all the wheels (to be used in animation)
    #declare P_Paint=pigment{image_map{jpeg "car_paint2" interpolate 2}}
    #declare N_Paint=normal{
        average
        normal_map{
            [1 bump_map{jpeg "bd_door2d_bump" interpolate 2}]
            [1 bumps 0.2 scale 0.15]
        }
    }
    #declare T_paint = texture{
        image_pattern{jpeg "bd_door2d_bump" interpolate 2}
        texture_map{
            [0 pigment{P_Paint}normal{N_Paint} finish{ambient 0 diffuse 1 }]
//            [1 pigment{P_Paint} normal{N_Paint} finish{ambient 0 diffuse 0.5 specular 1 roughness 1/1000 reflection {0.1*Ref, 1*Ref falloff 3 exponent 2}}]
            [1 pigment{average pigment_map{[1 P_Paint][2 color C_Paint]}} normal{N_Paint} finish{ambient 0 diffuse 0.5 specular 1 roughness 1/1000 reflection {0.1*Ref, 0.8*Ref falloff 3 exponent 2}}]
        }   
        scale 1
    }
    #declare T_roof = texture{pigment{C_Paint_Roof}finish{ambient 0 diffuse 1 roughness 1/45 specular 1/3 reflection {0.1*Ref, 0.5*Ref}}}
    #declare T_bolts = texture{pigment{White*0.4} finish{ambient 0 diffuse 1 brilliance 1 metallic}}
    #declare T_bottom = texture{pigment{White*0.2} finish{ambient 0 diffuse 1}}
    #declare T_bulb = texture{pigment{Clear}}
    #declare T_chrome = texture{pigment{rgb <1,0.9,0.8>*0.7} finish{ambient 0 diffuse 1 brilliance 5 metallic specular 1 roughness 1/200 reflection{0.4*Ref, 0.99*Ref}}}
    #declare T_chrome = texture{
        pigment{rgb <1,0.9,0.8>*0.7} 
        finish{ambient 0 diffuse 0.7 brilliance 5 metallic specular 1 roughness 1/200 
            reflection{0.2*Ref, 0.6*Ref}
        }
    }
    #declare T_counterface = texture{pigment{Black}finish{reflection 0.2*Ref}}
    #declare T_glass = texture{pigment{rgbf <0.7,0.7,0.7,0.8>} finish{ambient 0 diffuse 0.1 specular 1 roughness 1/1000 reflection{0.1*Ref,0.7*Ref}}}
    #declare T_glass_hlight = texture{
        pigment{image_map{jpeg "headlight" transmit all 0.2 interpolate 2}} 
        normal{bump_map{jpeg "headlight_bmp" interpolate 2} bump_size -2} 
        finish{ambient 0 diffuse 1 specular 0.3 roughness 1/30 reflection {0.2*Ref,0.99*Ref}}
    }
    #declare T_glass_blight = texture{pigment{rgbf <0.8,0.5,0.1,0.3>} finish{ambient 0 diffuse 1 specular 0.3 roughness 1/30 reflection 0.2*Ref}}
    #declare T_interior = texture{pigment{C_Paint_Interior}finish{ambient 0 diffuse 1}}
    #declare T_logo_centre = texture{        
        pigment{image_map{jpeg "mini_emblem" interpolate 2}} 
        finish{ambient 0 diffuse 0.5 reflection 0.2*Ref}
    }
    #declare T_mirror = texture{pigment{Black}finish{reflection 0.99*Ref}}
    #declare T_plastic_black = texture{pigment{White*0.2} finish{ambient 0 diffuse 1 specular 1 roughness 1/15}}
    #declare T_plate = texture{
        pigment{
            image_map{jpeg "lplate" interpolate 2}
        } 
        finish{ambient 0 diffuse 0.6 specular 0.2 roughness 1/15}
    }
    #declare T_plate_rim = texture{T_plastic_black}
    #declare T_rubber = texture{pigment{bozo color_map{[0 White*0.01][1 White*0.3]}} finish{ambient 0 diffuse 1}}
    #declare T_seat = texture{T_interior}
    #declare T_tlbottom = texture{pigment{rgbf <0.8,0.1,0.1,0.3>} finish{ambient 0 diffuse 1 specular 0.3 roughness 1/30 reflection 0.2*Ref}}
    #declare T_tltop = texture{pigment{rgbf <0.8,0.5,0.1,0.3>} finish{ambient 0 diffuse 1 specular 0.3 roughness 1/30 reflection 0.2*Ref}}
    #declare T_wheel = texture{T_chrome}
    
    #declare T_austin_mat = texture{T_chrome}
    #declare T_bl_ch_mat = texture{T_chrome}
    #declare T_bl_gl_mat = texture{T_glass_blight}
    #declare T_bmp_fr_mat = texture{T_chrome}
    #declare T_bmp_rear_mat = texture{T_chrome}
    #declare T_body_mat = texture{T_paint}
    #declare T_body2_mat = texture{T_paint scale 2}
    #declare T_bolts_fr_mat = texture{T_bolts}
    #declare T_bolts_rear_mat = texture{T_bolts}
    #declare T_bottom_fr_mat = texture{T_bottom}
    #declare T_bottom_mat = texture{T_bottom}
    #declare T_bs_bk_mat = texture{T_seat}
    #declare T_bs_bt_mat = texture{T_seat}
    #declare T_bt_ch_mat = texture{T_chrome}
    #declare T_cooper_mat = texture{T_chrome}
    #declare T_cterbase_mat = texture{T_plastic_black}
    #declare T_ctrface_mat = texture{T_counterface}
    #declare T_ctrrim_mat = texture{T_chrome}
    #declare T_dashboard_mat = texture{T_interior}
    #declare T_DEFAULT = texture{T_interior}
    #declare T_dw_rim_mat = texture{T_plastic_black}
    #declare T_dw2_mat = texture{T_chrome}
    #declare T_dw3_mat = texture{T_chrome}
    #declare T_dwshaft_mat = texture{T_plastic_black}
    #declare T_exhaust_mat = texture{T_chrome}
    #declare T_front_mat = texture{T_paint scale 2}
    #declare T_fs_bk_mat = texture{T_seat}
    #declare T_fs_bt_mat = texture{T_seat}
    #declare T_gascap_mat = texture{T_chrome}
    #declare T_gl_fr_mat = texture{T_glass}
    #declare T_gl_rear_mat = texture{T_glass}
    #declare T_gl_side1_mat = texture{T_glass}
    #declare T_gl_side2_mat = texture{T_glass}
    #declare T_gr_bk_mat = texture{T_paint}
    #declare T_gr_fr1_mat = texture{T_paint}
    #declare T_gr_fr2_mat = texture{T_paint}
    #declare T_handle_mat = texture{T_chrome}
    #declare T_hinge1_mat = texture{T_paint}
    #declare T_hinge2_mat = texture{T_paint}
    #declare T_hinge3_mat = texture{T_paint}
    #declare T_hinge4_mat = texture{T_paint}
    #declare T_hl_bulb_mat = texture{T_mirror}
    #declare T_hl_ch_mat = texture{T_chrome}
    #declare T_hl_gl_mat = texture{T_glass_hlight}
    #declare T_hl_mir_mat = texture{T_mirror}
    #declare T_hood_mat = texture{T_paint scale 2}
    #declare T_hoodtop_mat = texture{T_paint}
    #declare T_i_body1_mat = texture{T_interior}
    #declare T_i_body2_mat = texture{T_interior}
    #declare T_i_fl_rear_mat = texture{T_bottom}
    #declare T_i_floor_fr_mat = texture{T_bottom}
    #declare T_i_floor_mat = texture{T_interior}
    #declare T_i_floor2_mat = texture{T_interior}
    #declare T_i_handle1_mat = texture{T_chrome}
    #declare T_i_handle2_mat = texture{T_chrome}
    #declare T_i_handle3_mat = texture{T_chrome}
    #declare T_i_rear_mat = texture{T_interior}
    #declare T_i_roof_mat = texture{T_interior}
    #declare T_i_rv_mat = texture{T_chrome}
    #declare T_i_rvmir_mat = texture{T_mirror}
    #declare T_lgcentre_mat = texture{T_logo_centre}
    #declare T_lgwings_mat = texture{T_chrome}
    #declare T_lwip1_mat = texture{T_chrome}
    #declare T_lwip2_mat = texture{T_chrome}
    #declare T_pedal1_mat = texture{T_plastic_black}
    #declare T_pedal2_mat = texture{T_plastic_black}
    #declare T_pl_fr_mat = texture{T_plate}
    #declare T_pl_frrim_mat = texture{T_plastic_black}
    #declare T_pl_rear_mat = texture{T_plate}
    #declare T_pl_rrim_mat = texture{T_plastic_black}
    #declare T_radiator_mat = texture{T_chrome}
    #declare T_rear_hd_mat = texture{T_chrome}
    #declare T_rear_hinge_mat = texture{T_paint}
    #declare T_rear_mat = texture{T_paint}
    #declare T_roof_mat = texture{T_roof}
    #declare T_roof_trim_mat = texture{T_paint}
    #declare T_rv_side_mat = texture{T_chrome}
    #declare T_rv_sidemir_mat = texture{T_mirror}
    #declare T_rwip1_mat = texture{T_chrome}
    #declare T_rwip2_mat = texture{T_chrome}
    #declare T_sprinkler_mat = texture{T_plastic_black}
    #declare T_switch_mat = texture{T_plastic_black}
    #declare T_throthead_mat = texture{T_plastic_black}
    #declare T_throtrub_mat = texture{T_plastic_black}
    #declare T_throtshaft_mat = texture{T_chrome}
    #declare T_tl_ch_mat = texture{T_chrome}
    #declare T_tl_glbt_mat = texture{T_tlbottom}
    #declare T_tl_gltop_mat = texture{T_tltop}
    #declare T_tyre_fr_mat = texture{T_rubber}
    #declare T_tyre_rear_mat = texture{T_rubber}
    #declare T_wd_ch1_mat = texture{T_chrome}
    #declare T_wd_ch2_mat = texture{T_chrome}
    #declare T_wd_ch3_mat = texture{T_chrome}
    #declare T_wd_chbk_mat = texture{T_chrome}
    #declare T_wd_chfr_mat = texture{T_chrome}
    #declare T_wh_fr1_mat = texture{T_chrome}
    #declare T_wh_fr2_mat = texture{T_chrome}
    #declare T_wh_fr3_mat = texture{T_chrome}
    #declare T_wh_rear1_mat = texture{T_chrome}
    #declare T_wh_rear2_mat = texture{T_chrome}
    #declare T_wh_rear3_mat = texture{T_chrome}
    
    #include "mini_mesh_o.inc"
    #declare FrontWheel=union{
        object{ P_tyre_fr }
        object{ P_bolts_fr }
        object{ P_wh_fr3 }
        object{ P_wh_fr2 }
        object{ P_wh_fr1 }
    }
    #declare RearWheel=union{
        object{ P_wh_rear1 }
        object{ P_wh_rear2 }
        object{ P_wh_rear3 }
        object{ P_bolts_rear }
        object{ P_tyre_rear }
    }
       
    #declare Halfcar=union{
        
        union{
            object{ P_body }
            object{ P_hood }
            object{ P_rear }
            object{ P_body2 }
            object{ P_front }
            object{ P_hoodtop }
            object{ P_gr_bk }
            object{ P_gr_fr1 }
            object{ P_gr_fr2 }
            object{ P_rear_hinge }
            object{ P_hinge1 }
            object{ P_roof_trim }
            object{ P_hinge2 }
            object{ P_hinge4 }
            object{ P_hinge3 }
//            interior{ior 10}
        }
        object{ P_i_fl_rear }
        object{ P_i_floor }
        object{ P_i_floor_fr }
        object{ P_dashboard }
        object{ P_roof }
        object{ P_sprinkler }
        object{ P_radiator }
        object{ P_handle }
        object{ P_wd_ch1 }
        object{ P_wd_ch2 }
        object{ P_wd_ch3 }
        object{ P_wd_chfr }
        object{ P_wd_chbk }
        object{ P_bt_ch }
        object{ P_hl_gl }
        object{ P_hl_ch }
        object{ P_hl_bulb }
        object{ P_hl_mir }
        object{ P_bmp_fr }
        object{ P_bottom }
        object{ P_bottom_fr }
        object{ P_gascap }
        object{ P_tl_ch }
        object{ P_bmp_rear }
        object{ P_bl_gl }
        object{ P_bl_ch }
        
        #if (Ref=1) // excludes the glass panes from first pass
            object{ P_gl_fr }
            object{ P_gl_rear }
            object{ P_gl_side1 }
            object{ P_gl_side2 }
        #end
        
        object{ P_rv_side }
        object{ P_rv_sidemir }
        object{ P_rear_hd }
        object{ P_i_roof }
        object{ P_bs_bt }
        object{ P_fs_bk }
        object{ P_bs_bk }
        object{ P_i_rear }
        object{ P_i_body1 }
        object{ P_i_body2 }
        object{ P_fs_bt }
        object{ P_i_handle1 }
        object{ P_i_handle3 }
        object{ P_pedal2 }
        object{ P_pedal1 }
        object{ P_i_handle2 }
        object{ P_tl_gltop }
        object{ P_tl_glbt }
    }
    
    
    #declare MiniCooper=union{
        object{Halfcar}
        object{Halfcar scale <-1,1,1>}
        
        object{ P_exhaust }
        object{ P_switch }
        object{ P_i_rv }
        object{ P_i_rvmir }
        object{ P_dw_rim }
        object{ P_dw2 }
        object{ P_dw3 }
        object{ P_dwshaft }
        object{ P_throthead }
        object{ P_throtshaft }
        object{ P_throtrub }
        object{ P_lwip1 }
        object{ P_lwip2 }
        object{ P_rwip1 }
        object{ P_rwip2 }
        object{ P_cterbase }
        object{ P_ctrrim }
        object{ P_ctrface }
        object{ P_lgwings }
        object{ P_lgcentre }
        object{ P_pl_frrim }
        object{ P_pl_fr }
        object{ P_austin }
        object{ P_cooper }
        object{ P_pl_rrim }
        object{ P_pl_rear }
        object{ FrontWheel translate <-4.8,-4,-2> rotate x*angle_move rotate z*angle_turn translate <4.8,4,2>}
        object{ FrontWheel translate <-4.8,-4,-2> rotate x*(10+angle_move) rotate -z*angle_turn translate <4.8,4,2> scale <-1,1,1>}
        object{ RearWheel translate <-4.8,-19.5,-2> rotate x*(42+angle_move) translate <4.8,19.5,2>} 
        object{ RearWheel translate <-4.8,-19.5,-2> rotate x*(-10+angle_move) translate <4.8,19.5,2> scale <-1,1,1>} 

        rotate x*-90
        translate z*V_WorldBoundMax.y/2
        
        scale .1
        scale <-1,1,1>
        rotate y*180
        
    }

#end
